Stan Math Library: stan/math/prim/scal/fun/inverse_softmax.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
inverse_softmax.hpp File Reference
`#include <boost/math/tools/promotion.hpp>`
`#include <boost/throw_exception.hpp>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename Vector >
void | stan::math::inverse_softmax (const Vector &simplex, Vector &y)
| Writes the inverse softmax of the simplex argument into the second argument. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.